@@ -57,6 +57,21 @@ def test_transaction():
     assert response["connected"] is True
 
 
+def test_command():
+    nCard, port = get_serial_and_port()
+
+    response = nCard.Command({"cmd": "card.sleep"})
+
+    assert response is None
+
+
+def test_command_fail_if_req():
+    nCard, port = get_serial_and_port()
+
+    with pytest.raises(Exception, match="Please use 'cmd' instead of 'req'"):
+        nCard.Command({"req": "card.sleep"})
+
+
 def test_request_response():
     nCard, port = get_serial_and_port()
 
@@ -89,12 +104,13 @@ def test_hub_set():
     response = hub.set(nCard, product="com.blues.tester",
                        sn="foo",
                        mode="continuous",
-                       minutes=2,
-                       hours=1,
+                       outbound=2,
+                       inbound=60,
+                       duration=5,
                        sync=True,
                        align=True,
-                       vminutes="2.3",
-                       vhours="3.3",
+                       voutbound="2.3",
+                       vinbound="3.3",
                        host="http://hub.blues.foo")
 
     assert response == {}
@@ -196,7 +212,7 @@ def test_card_temp():
                              for char in
                              "{\"value\":33.625,\"calibration\":-3.0}\r\n"]
 
-    response = card.temp(nCard)
+    response = card.temp(nCard, minutes=20)
 
     assert "value" in response
     assert response["value"] == 33.625
@@ -211,7 +227,8 @@ def test_card_attn():
 
     response = card.attn(nCard, mode="arm, files",
                          files=["sensors.qo"],
-                         seconds=10)
+                         seconds=10, payload={"foo": "bar"},
+                         start=True)
 
     assert "set" in response
     assert response["set"] is True
@@ -242,7 +259,7 @@ def test_card_wireless():
                              for char in
                              "{\"status\":\"{modem-off}\",\"count\":1}\r\n"]
 
-    response = card.wireless(nCard, mode="auto")
+    response = card.wireless(nCard, mode="auto", apn="-")
 
     assert "status" in response
     assert response["status"] == "{modem-off}"
@@ -321,6 +338,21 @@ def test_note_changes():
     assert response["changes"] == 5
 
 
+def test_note_template():
+    nCard, port = get_serial_and_port()
+
+    port.read.side_effect = [char.encode('utf-8')
+                             for char in
+                             "{\"bytes\":40}\r\n"]
+
+    response = note.template(nCard, file="sensors.qo",
+                             body={"temp": 1.1, "hu": 1},
+                             length=5)
+
+    assert "bytes" in response
+    assert response["bytes"] == 40
+
+
 def test_debug_mode_on_serial():
     serial = Mock()  # noqa: F811
     port = serial.Serial("/dev/tty.foo", 9600)
@@ -341,6 +373,30 @@ def test_debug_mode_on_i2c():
     assert nCard._debug
 
 
+def test_env_default():
+    nCard, port = get_serial_and_port()
+
+    port.read.side_effect = [char.encode('utf-8')
+                             for char in
+                             "{}\r\n"]
+
+    response = env.default(nCard, name="pump", text="on")
+
+    assert response == {}
+
+
+def test_env_set():
+    nCard, port = get_serial_and_port()
+
+    port.read.side_effect = [char.encode('utf-8')
+                             for char in
+                             "{}\r\n"]
+
+    response = env.set(nCard, name="pump", text="on")
+
+    assert response == {}
+
+
 def test_env_get():
     nCard, port = get_serial_and_port()
 
@@ -353,6 +409,19 @@ def test_env_get():
     assert response == {}
 
 
+def test_env_modified():
+    nCard, port = get_serial_and_port()
+
+    port.read.side_effect = [char.encode('utf-8')
+                             for char in
+                             "{\"time\": 1605814493}\r\n"]
+
+    response = env.modified(nCard)
+
+    assert "time" in response
+    assert response["time"] == 1605814493
+
+
 def test_file_delete():
     nCard, port = get_serial_and_port()
 
